import setuptools
setuptools.setup(
    name = 'Mohammed_Ali',
    version = '0.1',
    author = 'Mohammed_Ali',
    description = 'simple Python library for dragging files ',
    packages = setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License"
    ]
)